@@ -15,8 +15,8 @@ from plotpy.styles import style_generator, update_style_attr
 from plotpy.tests import get_path
 from plotpy.tools import (
     EllipseTool,
-    FreeFormTool,
     MultiLineTool,
+    PolygonTool,
     RectangleTool,
     SegmentTool,
 )
@@ -35,7 +35,7 @@ def customize_shape(shape):
 
 def create_window():
     gridparam = make.gridparam(
-        background="black", minor_enabled=(False, False), major_style=(".", "gray", 1)
+        background="black", minor_enabled=(False, False), major_style=(":", "gray", 1)
     )
     win = make.dialog(
         edit=False,
@@ -43,13 +43,14 @@ def create_window():
         wintitle="All image and plot tools test",
         gridparam=gridparam,
         type="image",
+        size=(800, 600),
     )
     for toolklass in (
         RectangleTool,
         EllipseTool,
         SegmentTool,
         MultiLineTool,
-        FreeFormTool,
+        PolygonTool,
     ):
         win.manager.add_tool(toolklass, handle_final_shape_cb=customize_shape)
     return win
